@@ -3,7 +3,8 @@ import * as _ from 'lodash';
 import { Button, Split, SplitItem, Bullseye } from '@patternfly/react-core';
 import { K8sResourceKind, k8sPatch, K8sKind } from '@console/internal/module/k8s';
 import { AngleUpIcon, AngleDownIcon } from '@patternfly/react-icons';
-import { podRingLabel, usePodScalingAccessStatus } from '../../utils';
+import { useRelatedHPA } from '@console/dev-console/src/components/hpa/hooks';
+import { hpaPodRingLabel, podRingLabel, usePodScalingAccessStatus } from '../../utils';
 import { ExtPodKind } from '../../types';
 import PodStatus from './PodStatus';
 import './PodRing.scss';
@@ -28,7 +29,7 @@ const PodRing: React.FC<PodRingProps> = ({
   enableScaling = true,
 }) => {
   const [clickCount, setClickCount] = React.useState(obj.spec.replicas);
-  const isScalingAllowed = usePodScalingAccessStatus(
+  const isAccessScalingAllowed = usePodScalingAccessStatus(
     obj,
     resourceKind,
     pods,
@@ -67,8 +68,21 @@ const PodRing: React.FC<PodRingProps> = ({
     setClickCount(clickCount + operation);
     handleScaling(clickCount + operation);
   };
+
+  const {
+    apiVersion,
+    kind,
+    metadata: { name, namespace },
+  } = obj;
+  const [hpa] = useRelatedHPA(apiVersion, kind, name, namespace);
+  const hpaControlledScaling = !!hpa;
+
+  const isScalingAllowed = isAccessScalingAllowed && !hpaControlledScaling;
+
   const resourceObj = rc || obj;
-  const { title, subTitle, titleComponent } = podRingLabel(resourceObj, obj.kind, pods);
+  const { title, subTitle, titleComponent } = hpaControlledScaling
+    ? hpaPodRingLabel(resourceObj, hpa, pods)
+    : podRingLabel(resourceObj, kind, pods);
 
   return (
     <Split>
