@@ -1,15 +1,17 @@
 import * as _ from 'lodash';
+import { OverviewResourceUtil } from '@console/plugin-sdk';
 import {
   DeploymentKind,
   K8sResourceKind,
   LabelSelector,
   PodKind,
+  CronJobKind,
   PodTemplate,
   RouteKind,
   apiVersionForModel,
-  referenceForModel,
   K8sKind,
   ObjectMetadata,
+  JobKind,
 } from '@console/internal/module/k8s';
 import {
   DeploymentConfigModel,
@@ -19,9 +21,13 @@ import {
   DaemonSetModel,
   StatefulSetModel,
   PodModel,
+  JobModel,
+  CronJobModel,
 } from '@console/internal/models';
 import { getBuildNumber } from '@console/internal/module/k8s/builds';
-import { FirehoseResource } from '@console/internal/components/utils';
+import { ClusterServiceVersionKind } from '@console/operator-lifecycle-manager';
+import { Alert, Alerts } from '@console/internal/components/monitoring/types';
+import { alertMessageResources } from '@console/internal/components/monitoring/alerting';
 import {
   BuildConfigOverviewItem,
   OverviewItemAlerts,
@@ -43,116 +49,7 @@ import {
 } from '../constants';
 import { resourceStatus, podStatus } from './ResourceStatus';
 import { isKnativeServing, isIdled } from './pod-utils';
-import {
-  ClusterServiceVersionModel,
-  ClusterServiceVersionKind,
-} from '@console/operator-lifecycle-manager';
-
-export const getResourceList = (namespace: string, resList?: any) => {
-  let resources: FirehoseResource[] = [
-    {
-      isList: true,
-      kind: 'DeploymentConfig',
-      namespace,
-      prop: 'deploymentConfigs',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'Deployment',
-      namespace,
-      prop: 'deployments',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'DaemonSet',
-      namespace,
-      prop: 'daemonSets',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'Pod',
-      namespace,
-      prop: 'pods',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'ReplicationController',
-      namespace,
-      prop: 'replicationControllers',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'Route',
-      namespace,
-      prop: 'routes',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'Service',
-      namespace,
-      prop: 'services',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'ReplicaSet',
-      namespace,
-      prop: 'replicaSets',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'BuildConfig',
-      namespace,
-      prop: 'buildConfigs',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'Build',
-      namespace,
-      prop: 'builds',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'StatefulSet',
-      namespace,
-      prop: 'statefulSets',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: 'Secret',
-      namespace,
-      prop: 'secrets',
-      optional: true,
-    },
-    {
-      isList: true,
-      kind: referenceForModel(ClusterServiceVersionModel),
-      namespace,
-      prop: 'clusterServiceVersions',
-      optional: true,
-    },
-  ];
-
-  let utils = [];
-  if (resList) {
-    resList.forEach((resource) => {
-      resources = [...resources, ...resource.properties.resources(namespace)];
-      utils = [...utils, resource.properties.utils];
-    });
-  }
-
-  return { resources, utils };
-};
+import { doesHpaMatch } from '@console/dev-console/src/components/hpa/hpa-utils';
 
 export const getResourcePausedAlert = (resource: K8sResourceKind): OverviewItemAlerts => {
   if (!resource.spec.paused) {
@@ -485,23 +382,6 @@ export const getOperatorBackedServiceKindMap = (
       }, {})
     : {};
 
-export const isOperatorBackedService = (
-  obj: K8sResourceKind,
-  installedOperators: ClusterServiceVersionKind[],
-): boolean => {
-  const kind = _.get(obj, 'metadata.ownerReferences[0].kind', null);
-  const ownerUid = _.get(obj, 'metadata.ownerReferences[0].uid');
-  const operatBackedServiceKindMap = getOperatorBackedServiceKindMap(installedOperators);
-  const operatorResource: K8sResourceKind = _.find(installedOperators, {
-    metadata: { uid: ownerUid },
-  }) as K8sResourceKind;
-  return (
-    kind &&
-    operatBackedServiceKindMap &&
-    (!_.isEmpty(operatorResource) || kind in operatBackedServiceKindMap)
-  );
-};
-
 export const getPodsForResource = (resource: K8sResourceKind, resources: any): PodKind[] => {
   const { pods } = resources;
   return getOwnedResources(resource, pods.data);
@@ -615,6 +495,19 @@ export const getReplicaSetsForResource = (
   );
 };
 
+export const getJobsForCronJob = (cronJob: K8sResourceKind, resources: any): JobKind[] => {
+  if (!resources?.jobs?.data?.length) {
+    return [];
+  }
+  return resources.jobs.data
+    .filter((job) => job.metadata?.ownerReferences?.find((ref) => ref.uid === cronJob.metadata.uid))
+    .map((job) => ({
+      ...job,
+      apiVersion: apiVersionForModel(JobModel),
+      kind: JobModel.kind,
+    }));
+};
+
 export const getBuildsForResource = (
   buildConfig: K8sResourceKind,
   resources: any,
@@ -623,17 +516,48 @@ export const getBuildsForResource = (
   return getOwnedResources(buildConfig, builds.data);
 };
 
+export const getBuildConfigsForCronJob = (
+  cronJob: CronJobKind,
+  resources: any,
+): BuildConfigOverviewItem[] => {
+  const buildConfigs = resources?.buildConfigs?.data ?? [];
+  const currentNamespace = cronJob.metadata.namespace;
+  const containers = cronJob.spec?.jobTemplate?.spec?.template?.spec?.containers ?? [];
+  return _.reduce(
+    buildConfigs,
+    (acc, buildConfig) => {
+      const targetImageNamespace = buildConfig?.spec?.output?.to?.namespace ?? currentNamespace;
+      const targetImageName = buildConfig?.spec?.output?.to?.name;
+      if (
+        currentNamespace === targetImageNamespace &&
+        containers.find((container) => container.image?.endsWith(targetImageName))
+      ) {
+        const builds = getBuildsForResource(buildConfig, resources);
+        return [
+          ...acc,
+          {
+            ...buildConfig,
+            builds: sortBuilds(builds),
+          },
+        ];
+      }
+      return acc;
+    },
+    [],
+  );
+};
+
 export const getBuildConfigsForResource = (
   resource: K8sResourceKind,
   resources: any,
 ): BuildConfigOverviewItem[] => {
-  const buildConfigs = _.get(resources, ['buildConfigs', 'data']);
+  const buildConfigs = resources?.buildConfigs?.data;
   const currentNamespace = resource.metadata.namespace;
-  const nativeTriggers = _.get(resource, 'spec.triggers');
+  const nativeTriggers = resource?.spec?.triggers;
   const annotatedTriggers = getAnnotatedTriggers(resource);
   const triggers = _.unionWith(nativeTriggers, annotatedTriggers, _.isEqual);
   return _.flatMap(triggers, (trigger) => {
-    const triggerFrom = trigger.from || _.get(trigger, 'imageChangeParams.from', {});
+    const triggerFrom = trigger.from || (trigger.imageChangeParams?.from ?? {});
     if (triggerFrom.kind !== 'ImageStreamTag') {
       return [];
     }
@@ -642,12 +566,8 @@ export const getBuildConfigsForResource = (
       (acc, buildConfig) => {
         const triggerImageNamespace = triggerFrom.namespace || currentNamespace;
         const triggerImageName = triggerFrom.name;
-        const targetImageNamespace = _.get(
-          buildConfig,
-          'spec.output.to.namespace',
-          currentNamespace,
-        );
-        const targetImageName = _.get(buildConfig, 'spec.output.to.name');
+        const targetImageNamespace = buildConfig.spec?.output?.to?.namespace ?? currentNamespace;
+        const targetImageName = buildConfig.spec?.output?.to?.name;
         if (
           triggerImageNamespace === targetImageNamespace &&
           triggerImageName === targetImageName
@@ -710,232 +630,374 @@ export const getServicesForResource = (
   });
 };
 
-export const createDeploymentConfigItems = (
-  deploymentConfigs: K8sResourceKind[],
-  resources: any,
-  installedOperators: ClusterServiceVersionKind[],
-  utils?: Function[],
-  operatorsFilter?: boolean,
-): OverviewItem[] => {
-  const items = _.map(deploymentConfigs, (dc) => {
-    const obj: K8sResourceKind = {
-      ...dc,
-      apiVersion: apiVersionForModel(DeploymentConfigModel),
-      kind: DeploymentConfigModel.kind,
-    };
-    const { mostRecentRC, visibleReplicationControllers } = getReplicationControllersForResource(
-      obj,
-      resources,
-    );
-    const [current, previous] = visibleReplicationControllers;
-    const isRollingOut = getRolloutStatus(obj, current, previous);
-    const buildConfigs = getBuildConfigsForResource(obj, resources);
-    const services = getServicesForResource(obj, resources);
-    const routes = getRoutesForServices(services, resources);
-    const rolloutAlerts = mostRecentRC ? getReplicationControllerAlerts(mostRecentRC) : {};
-    const alerts = {
-      ...getResourcePausedAlert(obj),
-      ...getBuildAlerts(buildConfigs),
-      ...rolloutAlerts,
-    };
-    const status = resourceStatus(obj, current, isRollingOut);
-    const pods = [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])];
-    const overviewItems = {
-      alerts,
-      buildConfigs,
-      current,
-      isRollingOut,
-      obj,
-      previous,
-      pods,
-      routes,
-      services,
-      status,
-      isMonitorable: true,
-      isOperatorBackedService: isOperatorBackedService(obj, installedOperators),
-    };
-
-    if (utils) {
-      return utils.reduce((acc, element) => {
-        return { ...acc, ...element(obj, resources) };
-      }, overviewItems);
-    }
-    return overviewItems;
-  });
-  if (operatorsFilter !== undefined) {
-    return items.filter((item) => item.isOperatorBackedService === operatorsFilter);
+const isKindMonitorable = (model: K8sKind): boolean => {
+  switch (model) {
+    case DeploymentModel:
+    case DeploymentConfigModel:
+    case StatefulSetModel:
+    case DaemonSetModel:
+      return true;
+    default:
+      return false;
   }
-  return items;
+};
+
+export const getWorkloadMonitoringAlerts = (
+  resource: K8sResourceKind,
+  monitoringAlerts: Alerts,
+): Alert[] => {
+  const alerts = _.reduce(
+    monitoringAlerts?.data,
+    (acc, alert) => {
+      const labelValues = _.map(alertMessageResources, (model, label) => alert?.labels?.[label]);
+      if (_.find(labelValues, (val) => val === resource?.metadata?.name)) {
+        acc.push(alert);
+      }
+      return acc;
+    },
+    [],
+  );
+  return alerts;
+};
+
+export const getOverviewItemsForResource = (
+  obj: K8sResourceKind,
+  resources: any,
+  isMonitorable: boolean,
+  utils?: OverviewResourceUtil[],
+  current?: PodControllerOverviewItem,
+  previous?: PodControllerOverviewItem,
+  isRollingOut?: boolean,
+  customPods?: PodKind[],
+  additionalAlerts?: OverviewItemAlerts,
+  customBuildConfigs?: BuildConfigOverviewItem[],
+) => {
+  const monitoringAlerts = isMonitorable
+    ? getWorkloadMonitoringAlerts(obj, resources?.monitoringAlerts)
+    : undefined;
+  const buildConfigs = customBuildConfigs || getBuildConfigsForResource(obj, resources);
+  const services = getServicesForResource(obj, resources);
+  const routes = getRoutesForServices(services, resources);
+  const pods = customPods ?? getPodsForResource(obj, resources);
+  const alerts = {
+    ...(additionalAlerts ?? combinePodAlerts(pods)),
+    ...getBuildAlerts(buildConfigs),
+  };
+  const status = resourceStatus(obj, current, isRollingOut);
+  const overviewItems = {
+    alerts,
+    buildConfigs,
+    obj,
+    pods,
+    routes,
+    services,
+    status,
+    isMonitorable,
+    current,
+    previous,
+    isRollingOut,
+    monitoringAlerts,
+  };
+
+  if (utils) {
+    return utils.reduce((acc, util) => {
+      return { ...acc, ...util.properties.getResources(obj, resources) };
+    }, overviewItems);
+  }
+  return overviewItems;
+};
+
+export const createDeploymentConfigItem = (
+  deploymentConfig: K8sResourceKind,
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem => {
+  const { mostRecentRC, visibleReplicationControllers } = getReplicationControllersForResource(
+    deploymentConfig,
+    resources,
+  );
+  const [current, previous] = visibleReplicationControllers;
+  const isRollingOut = getRolloutStatus(deploymentConfig, current, previous);
+  const buildConfigs = getBuildConfigsForResource(deploymentConfig, resources);
+  const services = getServicesForResource(deploymentConfig, resources);
+  const routes = getRoutesForServices(services, resources);
+  const rolloutAlerts = mostRecentRC ? getReplicationControllerAlerts(mostRecentRC) : {};
+  const alerts = {
+    ...getResourcePausedAlert(deploymentConfig),
+    ...getBuildAlerts(buildConfigs),
+    ...rolloutAlerts,
+  };
+  const status = resourceStatus(deploymentConfig, current, isRollingOut);
+  const pods = [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])];
+  const monitoringAlerts = getWorkloadMonitoringAlerts(
+    deploymentConfig,
+    resources?.monitoringAlerts,
+  );
+  const hpas = resources?.hpas?.data?.filter(doesHpaMatch(deploymentConfig));
+  const overviewItems = {
+    alerts,
+    buildConfigs,
+    current,
+    hpas,
+    isRollingOut,
+    obj: deploymentConfig,
+    previous,
+    pods,
+    routes,
+    services,
+    status,
+    isMonitorable: true,
+    monitoringAlerts,
+  };
+
+  if (utils) {
+    return utils.reduce((acc, util) => {
+      return { ...acc, ...util.properties.getResources(deploymentConfig, resources) };
+    }, overviewItems);
+  }
+  return overviewItems;
+};
+
+export const createDeploymentConfigItems = (
+  deployments: K8sResourceKind[],
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem[] => {
+  if (!deployments) {
+    return [];
+  }
+  return deployments.map((d) => createDeploymentConfigItem(d, resources, utils));
+};
+
+export const createDeploymentItem = (
+  deployment: K8sResourceKind,
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem => {
+  const replicaSets = getReplicaSetsForResource(deployment, resources);
+  const [current, previous] = replicaSets;
+  const isRollingOut = !!current && !!previous;
+  const buildConfigs = getBuildConfigsForResource(deployment, resources);
+  const services = getServicesForResource(deployment, resources);
+  const routes = getRoutesForServices(services, resources);
+  const alerts = {
+    ...getResourcePausedAlert(deployment),
+    ...getBuildAlerts(buildConfigs),
+  };
+  const status = resourceStatus(deployment, current, isRollingOut);
+  const pods = [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])];
+  const monitoringAlerts = getWorkloadMonitoringAlerts(deployment, resources?.monitoringAlerts);
+  const hpas = resources?.hpas?.data?.filter(doesHpaMatch(deployment));
+  const overviewItem = {
+    obj: deployment,
+    alerts,
+    buildConfigs,
+    current,
+    hpas,
+    isRollingOut,
+    previous,
+    pods,
+    routes,
+    services,
+    status,
+    isMonitorable: true,
+    monitoringAlerts,
+  };
+  if (utils) {
+    return utils.reduce((acc, util) => {
+      return { ...acc, ...util.properties.getResources(deployment, resources) };
+    }, overviewItem);
+  }
+  return overviewItem;
 };
 
 export const createDeploymentItems = (
   deployments: DeploymentKind[],
   resources: any,
-  installedOperators: ClusterServiceVersionKind[],
-  utils?: Function[],
-  operatorsFilter?: boolean,
-): OverviewItem<DeploymentKind>[] => {
-  const items = _.map(deployments, (d) => {
-    const obj: DeploymentKind = {
-      ...d,
-      apiVersion: apiVersionForModel(DeploymentModel),
-      kind: DeploymentModel.kind,
-    };
-    const replicaSets = getReplicaSetsForResource(obj, resources);
-    const [current, previous] = replicaSets;
-    const isRollingOut = !!current && !!previous;
-    const buildConfigs = getBuildConfigsForResource(obj, resources);
-    const services = getServicesForResource(obj, resources);
-    const routes = getRoutesForServices(services, resources);
-    const alerts = {
-      ...getResourcePausedAlert(obj),
-      ...getBuildAlerts(buildConfigs),
-    };
-    const status = resourceStatus(obj, current, isRollingOut);
-    const pods = [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])];
-    const overviewItems = {
-      alerts,
-      buildConfigs,
-      current,
-      isRollingOut,
-      obj,
-      previous,
-      pods,
-      routes,
-      services,
-      status,
-      isMonitorable: true,
-      isOperatorBackedService: isOperatorBackedService(obj, installedOperators),
-    };
-
-    if (utils) {
-      return utils.reduce((acc, element) => {
-        return { ...acc, ...element(obj, resources) };
-      }, overviewItems);
-    }
-    return overviewItems;
-  });
-  if (operatorsFilter !== undefined) {
-    return items.filter((item) => item.isOperatorBackedService === operatorsFilter);
-  }
-  return items;
-};
-
-export const createDaemonSetItems = (
-  daemonSets: K8sResourceKind[],
-  resources: any,
-  installedOperators: ClusterServiceVersionKind[],
-  utils?: Function[],
-  operatorsFilter?: boolean,
+  utils?: OverviewResourceUtil[],
 ): OverviewItem[] => {
-  const items = _.map(daemonSets, (ds) => {
-    const obj: K8sResourceKind = {
-      ...ds,
-      apiVersion: apiVersionForModel(DaemonSetModel),
-      kind: DaemonSetModel.kind,
-    };
-    const buildConfigs = getBuildConfigsForResource(obj, resources);
-    const services = getServicesForResource(obj, resources);
-    const routes = getRoutesForServices(services, resources);
-    const pods = getPodsForResource(obj, resources);
-    const alerts = {
-      ...combinePodAlerts(pods),
-      ...getBuildAlerts(buildConfigs),
-    };
-    const status = resourceStatus(obj);
-    return {
-      alerts,
-      buildConfigs,
-      obj,
-      pods,
-      routes,
-      services,
-      status,
-      isMonitorable: true,
-      isOperatorBackedService: isOperatorBackedService(obj, installedOperators),
-    };
-  });
-  if (operatorsFilter !== undefined) {
-    return items.filter((item) => item.isOperatorBackedService === operatorsFilter);
+  if (!deployments) {
+    return [];
   }
-  return items;
+  return deployments.map((d) => createDeploymentItem(d, resources, utils));
 };
 
-export const createStatefulSetItems = (
-  statefulSets: K8sResourceKind[],
+export const createCronJobItem = (
+  cronJob: CronJobKind,
   resources: any,
-  installedOperators: ClusterServiceVersionKind[],
-  utils?: Function[],
-  operatorsFilter?: boolean,
-): OverviewItem[] => {
-  const items = _.map(statefulSets, (ss) => {
-    const obj: K8sResourceKind = {
-      ...ss,
-      apiVersion: apiVersionForModel(StatefulSetModel),
-      kind: StatefulSetModel.kind,
-    };
-    const buildConfigs = getBuildConfigsForResource(obj, resources);
-    const pods = getPodsForResource(obj, resources);
-    const alerts = {
-      ...combinePodAlerts(pods),
-      ...getBuildAlerts(buildConfigs),
-    };
-    const services = getServicesForResource(obj, resources);
-    const routes = getRoutesForServices(services, resources);
-    const status = resourceStatus(obj);
-    return {
-      alerts,
-      buildConfigs,
-      obj,
-      pods,
-      routes,
-      services,
-      status,
-      isMonitorable: true,
-      isOperatorBackedService: isOperatorBackedService(obj, installedOperators),
-    };
-  });
-  if (operatorsFilter !== undefined) {
-    return items.filter((item) => item.isOperatorBackedService === operatorsFilter);
+  utils?: OverviewResourceUtil[],
+): OverviewItem => {
+  const buildConfigs = getBuildConfigsForCronJob(cronJob, resources);
+  const jobs = getJobsForCronJob(cronJob, resources);
+  const pods = jobs?.reduce((acc, job) => {
+    acc.push(...getPodsForResource(job, resources));
+    return acc;
+  }, []);
+  const alerts = {
+    ...combinePodAlerts(pods),
+    ...getBuildAlerts(buildConfigs),
+  };
+  const status = resourceStatus(cronJob);
+  const isMonitorable = isKindMonitorable(CronJobModel);
+  const monitoringAlerts = isMonitorable
+    ? getWorkloadMonitoringAlerts(cronJob, resources?.monitoringAlerts)
+    : undefined;
+  const overviewItem = {
+    alerts,
+    obj: cronJob,
+    buildConfigs,
+    pods,
+    jobs,
+    status,
+    routes: [],
+    services: [],
+    isMonitorable,
+    monitoringAlerts,
+  };
+
+  if (utils) {
+    return utils.reduce((acc, util) => {
+      return { ...acc, ...util.properties.getResources(cronJob, resources) };
+    }, overviewItem);
   }
-  return items;
+  return overviewItem;
 };
 
-export const createPodItems = (resources: any): OverviewItem[] => {
-  const { pods } = resources;
-  return _.reduce(
-    pods.data,
-    (acc, pod) => {
-      const obj: PodKind = {
-        ...pod,
-        apiVersion: apiVersionForModel(PodModel),
-        kind: PodModel.kind,
-      };
-      const owners = _.get(obj, 'metadata.ownerReferences');
-      const phase = _.get(obj, 'status.phase');
-      if (!_.isEmpty(owners) || phase === 'Succeeded' || phase === 'Failed') {
-        return acc;
-      }
+export const createCronJobItems = (
+  cronJobs: CronJobKind[],
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem[] => {
+  if (!cronJobs) {
+    return [];
+  }
+  return cronJobs.map((d) => createCronJobItem(d, resources, utils));
+};
 
-      const alerts = getPodAlerts(obj);
-      const services = getServicesForResource(obj, resources);
-      const routes = getRoutesForServices(services, resources);
-      const status = podStatus(obj);
-      return [
-        ...acc,
-        {
-          alerts,
-          obj,
-          routes,
-          services,
-          status,
-        },
-      ];
-    },
-    [],
+const isStandaloneJob = (job: K8sResourceKind) =>
+  !_.find(job.metadata?.ownerReferences, (owner) => owner.kind === CronJobModel.kind);
+
+export const getStandaloneJobs = (jobs: JobKind[]) => jobs.filter((job) => isStandaloneJob(job));
+
+export const createWorkloadItems = (
+  model: K8sKind,
+  typedItems: K8sResourceKind[],
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem[] => {
+  if (!typedItems) {
+    return [];
+  }
+  return typedItems.map((d) =>
+    getOverviewItemsForResource(d, resources, isKindMonitorable(model), utils),
   );
 };
 
+export const createPodItem = (pod: PodKind, resources: any): OverviewItem => {
+  const owners = pod?.metadata?.ownerReferences;
+  const phase = pod?.status?.phase;
+  if (!_.isEmpty(owners) || phase === 'Succeeded' || phase === 'Failed') {
+    return null;
+  }
+  const alerts = getPodAlerts(pod);
+  const services = getServicesForResource(pod, resources);
+  const routes = getRoutesForServices(services, resources);
+  const status = podStatus(pod as PodKind);
+  const isMonitorable = isKindMonitorable(PodModel);
+  const monitoringAlerts: Alert[] = isMonitorable
+    ? getWorkloadMonitoringAlerts(pod, resources?.monitoringAlerts)
+    : undefined;
+
+  return {
+    alerts,
+    obj: pod,
+    buildConfigs: null,
+    routes,
+    services,
+    status,
+    pods: [pod],
+    isMonitorable,
+    monitoringAlerts,
+  };
+};
+
+export const createPodItems = (pods: K8sResourceKind[], resources: any): OverviewItem[] => {
+  if (!pods) {
+    return [];
+  }
+  return pods.reduce((acc, p) => {
+    const item = createPodItem(p as PodKind, resources);
+    if (item) {
+      acc.push(item);
+    }
+    return acc;
+  }, []);
+};
+
+export const createOverviewItemsForType = (
+  type: string,
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem[] => {
+  const typedItems = resources[type]?.data ?? [];
+  switch (type) {
+    case 'deployments':
+      return createDeploymentItems(typedItems, resources, utils);
+    case 'deploymentConfigs':
+      return createDeploymentConfigItems(typedItems, resources, utils);
+    case 'cronJobs':
+      return createCronJobItems(typedItems, resources, utils);
+    case 'statefulSets':
+      return createWorkloadItems(StatefulSetModel, typedItems, resources, utils);
+    case 'daemonSets':
+      return createWorkloadItems(DaemonSetModel, typedItems, resources, utils);
+    case 'jobs':
+      return createWorkloadItems(JobModel, getStandaloneJobs(typedItems), resources, utils);
+    case 'pods':
+      return createPodItems(typedItems, resources);
+    default:
+      return [];
+  }
+};
+
+export const createOverviewItemForType = (
+  type: string,
+  resource: K8sResourceKind,
+  resources: any,
+  utils?: OverviewResourceUtil[],
+): OverviewItem => {
+  switch (type) {
+    case 'deployments':
+      return createDeploymentItem(resource, resources, utils);
+    case 'deploymentConfigs':
+      return createDeploymentConfigItem(resource, resources, utils);
+    case 'cronJobs':
+      return createCronJobItem(resource as CronJobKind, resources, utils);
+    case 'statefulSets':
+      return getOverviewItemsForResource(
+        resource,
+        resources,
+        isKindMonitorable(StatefulSetModel),
+        utils,
+      );
+    case 'daemonSets':
+      return getOverviewItemsForResource(
+        resource,
+        resources,
+        isKindMonitorable(DaemonSetModel),
+        utils,
+      );
+    case 'jobs':
+      return isStandaloneJob(resource)
+        ? getOverviewItemsForResource(resource, resources, isKindMonitorable(JobModel), utils)
+        : null;
+    case 'pods':
+      return createPodItem(resource as PodKind, resources);
+    default:
+      return undefined;
+  }
+};
+
 export const getPodsForDeploymentConfigs = (
   deploymentConfigs: K8sResourceKind[],
   resources: any,
