@@ -62,6 +62,7 @@ export interface DeployImageFormData {
   application: ApplicationData;
   name: string;
   searchTerm: string;
+  allowInsecureRegistry: boolean;
   registry: string;
   imageStream: {
     image: string;
@@ -71,6 +72,7 @@ export interface DeployImageFormData {
   };
   isi: ImageStreamImageData;
   image: ImageStreamImageData;
+  runtimeIcon?: string;
   isSearchingForImage: boolean;
   resources: Resources;
   resourceTypesNotValid?: Resources[];
@@ -95,6 +97,7 @@ export interface GitImportFormData {
   serverless?: ServerlessData;
   pipeline?: PipelineData;
   image: ImageData;
+  runtimeIcon?: string;
   route: RouteData;
   resources: Resources;
   resourceTypesNotValid?: Resources[];
@@ -109,6 +112,7 @@ export interface ApplicationData {
   initial?: string;
   name: string;
   selectedKey: string;
+  isInContext?: boolean;
 }
 
 export interface ImageData {
@@ -294,6 +298,7 @@ export enum ImportOptions {
   DOCKERFILE = 'DOCKERFILE',
   DATABASE = 'DATABASE',
   EVENTSOURCE = 'EVENTSOURCE',
+  EVENTPUBSUB = 'EVENTPUBSUB',
 }
 
 export interface HealthChecksData {
