@@ -1,6 +1,7 @@
 import * as React from 'react';
 import { Alert } from '@patternfly/react-core';
 import { Pipeline, PipelineRun } from '../../../../utils/pipeline-augment';
+import { hasInlineTaskSpec } from '../../../../utils/pipeline-utils';
 import PipelineTopologyGraph from '../../pipeline-topology/PipelineTopologyGraph';
 import { getTopologyNodesEdges } from '../../pipeline-topology/utils';
 import { PipelineLayout } from '../../pipeline-topology/const';
@@ -17,23 +18,32 @@ const PipelineVisualization: React.FC<PipelineTopologyVisualizationProps> = ({
   pipelineRun,
 }) => {
   const { nodes, edges } = getTopologyNodesEdges(pipeline, pipelineRun);
-
-  if (nodes.length === 0 && edges.length === 0) {
+  let content: React.ReactElement;
+  if (hasInlineTaskSpec(pipeline)) {
+    // TODO: Inline taskSpec is not yet supported feature
+    content = (
+      <Alert
+        variant="info"
+        isInline
+        title="This Pipeline cannot be visualized. Pipeline taskSpec is not supported."
+      />
+    );
+  } else if (nodes.length === 0 && edges.length === 0) {
     // Nothing to render
     // TODO: Confirm wording with UX; ODC-1860
-    return <Alert variant="info" isInline title="This Pipeline has no tasks to visualize." />;
-  }
-
-  return (
-    <div className="odc-pipeline-visualization">
+    content = <Alert variant="info" isInline title="This Pipeline has no tasks to visualize." />;
+  } else {
+    content = (
       <PipelineTopologyGraph
         id={pipelineRun?.metadata?.name || pipeline.metadata.name}
         nodes={nodes}
         edges={edges}
         layout={PipelineLayout.DAGRE_VIEWER}
       />
-    </div>
-  );
+    );
+  }
+
+  return <div className="odc-pipeline-visualization">{content}</div>;
 };
 
 export default PipelineVisualization;
