@@ -28,10 +28,10 @@ const nodeQueriesByNodeName = {
   [HostQuery.MEMORY_UTILIZATION]: _.template(`node_memory_Active_bytes{instance=~'<%= node %>'}`),
   [HostQuery.MEMORY_TOTAL]: _.template(`node_memory_MemTotal_bytes{instance=~'<%= node %>'}`),
   [HostQuery.STORAGE_UTILIZATION]: _.template(
-    `sum(node_filesystem_size_bytes{instance="<%= node %>",fstype!~"tmpfs|squashfs",mountpoint!~"/usr|/var"} - node_filesystem_avail_bytes{instance="<%= node %>",fstype!~"tmpfs|squashfs",mountpoint!~"/usr|/var"})`,
+    `sum(node_filesystem_size_bytes{instance="<%= node %>",mountpoint="/var"} - node_filesystem_avail_bytes{instance="<%= node %>",mountpoint="/var"})`,
   ),
   [HostQuery.STORAGE_TOTAL]: _.template(
-    `sum(node_filesystem_size_bytes{instance='<%= node %>',fstype!~"tmpfs|squashfs",mountpoint!~"/usr|/var"})`,
+    `sum(node_filesystem_size_bytes{instance='<%= node %>',mountpoint="/var"})`,
   ),
   [HostQuery.NETWORK_IN_UTILIZATION]: _.template(
     `instance:node_network_receive_bytes:rate:sum{instance=~'<%= node %>'}`,
