@@ -1,8 +1,11 @@
 import * as React from 'react';
 
+import PodRingSet from '@console/shared/src/components/pod/PodRingSet';
+import { PodRingController } from '@console/shared';
+import { AddHealthChecks, EditHealthChecks } from '@console/app/src/actions/modify-health-checks';
 import { K8sResourceKind } from '../module/k8s';
 import { ResourceEventStream } from './events';
-import { DetailsPage, ListPage, Table } from './factory';
+import { DetailsPage, ListPage, Table, RowFunction } from './factory';
 
 import { WorkloadTableRow, WorkloadTableHeader } from './workload-table';
 
@@ -14,42 +17,36 @@ import {
   ResourceSummary,
   SectionHeading,
   navFactory,
+  LoadingInline,
+  PodsComponent,
 } from './utils';
 import { VolumesTable } from './volumes-table';
 import { StatefulSetModel } from '../models';
 
-const { AddStorage, common } = Kebab.factory;
+const { AddStorage, common, ModifyCount } = Kebab.factory;
 export const menuActions: KebabAction[] = [
+  AddHealthChecks,
+  ModifyCount,
   AddStorage,
   ...Kebab.getExtensionsActionsForKind(StatefulSetModel),
+  EditHealthChecks,
   ...common,
 ];
 
 const kind = 'StatefulSet';
 
-const StatefulSetTableRow = ({
-  obj,
-  index,
-  key,
-  style,
-}: {
-  obj: K8sResourceKind;
-  index: number;
-  key: string;
-  style: any;
-}) => {
+const StatefulSetTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <WorkloadTableRow
       obj={obj}
       index={index}
-      key={key}
+      rowKey={key}
       style={style}
       menuActions={menuActions}
       kind={kind}
     />
   );
 };
-StatefulSetTableRow.displayName = 'StatefulSetTableRow';
 
 const StatefulSetTableHeader = () => {
   return WorkloadTableHeader();
@@ -60,6 +57,23 @@ const StatefulSetDetails: React.FC<StatefulSetDetailsProps> = ({ obj: ss }) => (
   <>
     <div className="co-m-pane__body">
       <SectionHeading text="StatefulSet Details" />
+      <PodRingController
+        namespace={ss.metadata.namespace}
+        kind={ss.kind}
+        render={(d) => {
+          return d.loaded ? (
+            <PodRingSet
+              key={ss.metadata.uid}
+              podData={d.data[ss.metadata.uid]}
+              obj={ss}
+              resourceKind={StatefulSetModel}
+              path="/spec/replicas"
+            />
+          ) : (
+            <LoadingInline />
+          );
+        }}
+      />
       <ResourceSummary resource={ss} showPodSelector showNodeSelector showTolerations />
     </div>
     <div className="co-m-pane__body">
@@ -102,10 +116,14 @@ export const StatefulSetsPage: React.FC<StatefulSetsPageProps> = (props) => (
   <ListPage {...props} ListComponent={StatefulSetsList} kind={kind} canCreate={true} />
 );
 
+const StatefulSetPods: React.FC<StatefulSetPodsProps> = (props) => (
+  <PodsComponent {...props} customData={{ showNodes: true }} />
+);
+
 const pages = [
   navFactory.details(StatefulSetDetails),
   navFactory.editYaml(),
-  navFactory.pods(),
+  navFactory.pods(StatefulSetPods),
   navFactory.envEditor(EnvironmentTab),
   navFactory.events(ResourceEventStream),
 ];
@@ -135,6 +153,10 @@ type StatefulSetsPageProps = {
   selector?: any;
 };
 
+type StatefulSetPodsProps = {
+  obj: K8sResourceKind;
+};
+
 type StatefulSetsDetailsPageProps = {
   match: any;
 };
